@@ -855,7 +855,7 @@ class Bot(hikari.BotApp):
             await self._dispatch_command_error_event_from_exception(ex, event.message, context, command)
             return
         except Exception as ex:
-            new_ex = errors.CommandInvocationError(f"{type(ex).__name__}: {ex}", original=ex)
+            new_ex = errors.CommandInvocationError(text=f"{type(ex).__name__}: {ex}", original=ex)
             await self._dispatch_command_error_event_from_exception(new_ex, event.message, context, command)
             return
 
