@@ -53,57 +53,44 @@ import attr
 import hikari
 
 from lightbulb import commands
-from lightbulb import context as context_
 
 
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class LightbulbError(Exception):
     """Base for any exception raised by lightbulb."""
 
 
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class ExtensionError(LightbulbError):
     """Base exception for errors incurred during the loading and unloading of extensions."""
 
-    pass
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class ExtensionAlreadyLoaded(ExtensionError):
     """Exception raised when an extension already loaded is attempted to be loaded."""
 
-    pass
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class ExtensionNotLoaded(ExtensionError):
     """Exception raised when an extension not already loaded is attempted to be unloaded."""
 
-    pass
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class ExtensionMissingLoad(ExtensionError):
     """Exception raised when an extension is attempted to be loaded but does not contain a load function"""
 
-    pass
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class ExtensionMissingUnload(ExtensionError):
     """Exception raised when an extension is attempted to be unloaded but does not contain an unload function"""
 
-    pass
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class CommandError(LightbulbError):
     """Base exception for errors incurred during handling of commands."""
 
-    pass
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class CommandNotFound(CommandError):
     """
     Exception raised when a command when attempted to be invoked but one with that name could not be found.
@@ -113,7 +100,7 @@ class CommandNotFound(CommandError):
     """The command string that was attempted to be invoked."""
 
 
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class NotEnoughArguments(CommandError):
     """
     Exception raised when a command is run without a sufficient number of arguments.
@@ -123,7 +110,7 @@ class NotEnoughArguments(CommandError):
     """The command string that was attempted to be invoked."""
 
 
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class TooManyArguments(CommandError):
     """
     Exception raised when a command is run with too many arguments, and the command has been
@@ -134,16 +121,14 @@ class TooManyArguments(CommandError):
     """The command string that was attempted to be invoked."""
 
 
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class ConverterFailure(CommandError):
     """
     Exception raised when a converter for a command argument fails.
     """
 
-    pass
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class CommandIsOnCooldown(CommandError):
     """
     Exception raised when a command is attempted to be run but is currently on cooldown.
@@ -159,7 +144,7 @@ class CommandIsOnCooldown(CommandError):
     """Number of seconds remaining for the cooldown."""
 
 
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class CommandSyntaxError(CommandError, abc.ABC):
     """
     Base error raised if a syntax issue occurs parsing invocation arguments.
@@ -171,7 +156,7 @@ class CommandSyntaxError(CommandError, abc.ABC):
         ...
 
 
-@attr.s(slots=True, auto_exc=True, init=False)
+@attr.s(slots=True, init=False, weakref_slot=False)
 class PrematureEOF(CommandSyntaxError):
     """
     Error raised if EOF (end of input) was reached, but more content was
@@ -183,7 +168,7 @@ class PrematureEOF(CommandSyntaxError):
         super().__init__()
 
 
-@attr.s(slots=True, auto_exc=True, init=False)
+@attr.s(slots=True, init=False, weakref_slot=False)
 class UnclosedQuotes(CommandSyntaxError):
     """
     Error raised when no closing quote is found for a quoted argument.
@@ -198,107 +183,91 @@ class UnclosedQuotes(CommandSyntaxError):
         self.text = text
 
 
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class CheckFailure(CommandError):
     """
     Base error that is raised when a check fails for a command. Anything raised by a check
     should inherit from this class.
     """
 
-    pass
+    text: typing.Optional[str] = attr.ib(default=None)
+    """The error text."""
 
 
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class OnlyInGuild(CheckFailure):
     """
     Error raised when a command marked as guild only is attempted to be invoked in DMs.
     """
 
-    text: str = attr.ib()
-    """The error text."""
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class OnlyInDM(CheckFailure):
     """
     Error raised when a command marked as DM only is attempted to be invoked in a guild.
     """
 
-    text: str = attr.ib()
-    """The error text."""
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class NotOwner(CheckFailure):
     """
     Error raised when a command marked as owner only is attempted to be invoked by another user.
     """
 
-    text: str = attr.ib()
-    """The error text."""
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class BotOnly(CheckFailure):
     """
     Error raised when the command invoker is not a bot.
     """
 
-    pass
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class HumanOnly(CheckFailure):
     """
     Error raised when the command invoker is not an human.
     """
 
-    pass
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class NSFWChannelOnly(CheckFailure):
     """
     Error raised when a command that must be invoked in an NSFW channel is attempted to be invoked outside of one.
     """
 
-    pass
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class MissingRequiredRole(CheckFailure):
     """
     Error raised when the member invoking a command is missing one or more role required.
     """
 
-    pass
 
-
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class MissingRequiredPermission(CheckFailure):
     """
     Error raised when the member invoking a command is missing one or more permission required.
     """
 
-    text: str = attr.ib()
+    text: typing.Optional[str] = attr.ib(default=None)
     """The error text."""
     permissions: hikari.Permissions = attr.ib(kw_only=True)
     """Permission(s) the bot is missing."""
 
 
-@attr.s(slots=True, auto_exc=True)
+@attr.s(slots=True, weakref_slot=False)
 class BotMissingRequiredPermission(CheckFailure):
     """
     Error raised when the bot is missing one or more permission required for the command to be run.
     """
 
-    text: str = attr.ib()
+    text: typing.Optional[str] = attr.ib(default=None)
     """The error text."""
     permissions: hikari.Permissions = attr.ib(kw_only=True)
     """Permission(s) the bot is missing."""
 
 
-@attr.s(slots=True, auto_exc=True, init=False)
+@attr.s(slots=True, weakref_slot=False)
 class CommandInvocationError(CommandError):
     """
     Error raised if an error is encountered during command invocation. This will only be raised
@@ -308,14 +277,9 @@ class CommandInvocationError(CommandError):
 
     text: str = attr.ib()
     """The error text."""
+    original: Exception = attr.ib()
+    """The original exception that caused this to be raised."""
 
-    # XXX: deprecate this and use `__cause__` instead, either manually setting it or
-    # using `raise x from original`
     @property
-    def original(self) -> Exception:
-        return self.__cause__
-
-    def __init__(self, text: str, *, original: Exception) -> None:
-        self.text = text
-        """The error text."""
-        self.__cause__ = cause
+    def __cause__(self) -> Exception:
+        return self.original
