@@ -17,7 +17,17 @@
 # along with Lightbulb. If not, see <https://www.gnu.org/licenses/>.
 from __future__ import annotations
 
-__all__: typing.List[str] = ["StringNavigator", "EmbedNavigator", "Navigator", "NavButton"]
+__all__: typing.List[str] = [
+    "StringNavigator",
+    "EmbedNavigator",
+    "Navigator",
+    "NavButton",
+    "next_page",
+    "prev_page",
+    "first_page",
+    "last_page",
+    "stop",
+]
 
 import abc
 import asyncio
@@ -43,8 +53,10 @@ class NavButton:
     def __init__(
         self,
         emoji: typing.Union[str, hikari.Emoji],
-        callback: typing.Callable[[hikari.ReactionAddEvent], typing.Coroutine[typing.Any, typing.Any, None]],
+        callback: typing.Callable[[Navigator, hikari.ReactionAddEvent], typing.Coroutine[typing.Any, typing.Any, None]],
     ) -> None:
+        if isinstance(emoji, str):
+            emoji = hikari.Emoji.parse(emoji)
         self.emoji = emoji
         self.callback = callback
 
@@ -58,21 +70,61 @@ class NavButton:
         Returns:
             :obj:`bool`: Whether or not the button is pressed in the given event.
         """
-        return str(event.emoji) == str(self.emoji)
+        return event.emoji.mention == self.emoji.mention
 
-    def press(self, event: hikari.ReactionAddEvent) -> typing.Coroutine[typing.Any, typing.Any, None]:
+    def press(self, nav: Navigator, event: hikari.ReactionAddEvent) -> typing.Coroutine[typing.Any, typing.Any, None]:
         """
         Call the button's callback coroutine and return the awaitable.
 
         Returns:
             Coroutine[``None``, Any, ``None``]: Returned awaitable from the coroutine call.
         """
-        return self.callback(event)
+        return self.callback(nav, event)
 
 
 T = typing.TypeVar("T")
 
 
+async def next_page(nav: Navigator, _) -> None:
+    """
+    :obj:`NavButton` callback to make the navigator go to the next page.
+    """
+    nav.current_page_index += 1
+    nav.current_page_index %= len(nav.pages)
+
+
+async def prev_page(nav: Navigator, _) -> None:
+    """
+    :obj:`NavButton` callback to make the navigator go to the previous page.
+    """
+    nav.current_page_index -= 1
+    if nav.current_page_index < 0:
+        nav.current_page_index = len(nav.pages) - 1
+
+
+async def first_page(nav: Navigator, _) -> None:
+    """
+    :obj:`NavButton` callback to make the navigator go to the first page.
+    """
+    nav.current_page_index = 0
+
+
+async def last_page(nav: Navigator, _) -> None:
+    """
+    :obj:`NavButton` callback to make the navigator go to the last page.
+    """
+    nav.current_page_index = len(nav.pages) - 1
+
+
+async def stop(nav: Navigator, _) -> None:
+    """
+    :obj:`NavButton` callback to make the navigator stop navigation.
+    """
+    nav._msg.app.unsubscribe(hikari.ReactionAddEvent, nav._process_reaction_add)
+    await nav._msg.delete()
+    nav._msg = None
+
+
 class Navigator(abc.ABC, typing.Generic[T]):
     def __init__(
         self,
@@ -85,8 +137,12 @@ class Navigator(abc.ABC, typing.Generic[T]):
             raise ValueError("You cannot pass fewer than 1 page to the navigator.")
         self.pages: typing.Sequence[T] = tuple(pages)
 
+        if buttons is not None:
+            if any(not isinstance(btn, NavButton) for btn in buttons):
+                raise TypeError("Buttons must be an instance of NavButton")
+
         if len(self.pages) == 1 and not buttons:
-            self.buttons = [NavButton("\N{BLACK SQUARE FOR STOP}", self._stop)]
+            self.buttons = [NavButton("\N{BLACK SQUARE FOR STOP}", stop)]
         else:
             self.buttons: typing.Sequence[NavButton] = buttons if buttons is not None else self.create_default_buttons()
 
@@ -106,34 +162,14 @@ class Navigator(abc.ABC, typing.Generic[T]):
 
     def create_default_buttons(self) -> typing.Sequence[NavButton]:
         buttons = (
-            NavButton("\N{BLACK LEFT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR}", self._first),
-            NavButton("\N{BLACK LEFT-POINTING TRIANGLE}", self._prev),
-            NavButton("\N{BLACK SQUARE FOR STOP}", self._stop),
-            NavButton("\N{BLACK RIGHT-POINTING TRIANGLE}", self._next),
-            NavButton("\N{BLACK RIGHT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR}", self._last),
+            NavButton("\N{BLACK LEFT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR}", first_page),
+            NavButton("\N{BLACK LEFT-POINTING TRIANGLE}", prev_page),
+            NavButton("\N{BLACK SQUARE FOR STOP}", stop),
+            NavButton("\N{BLACK RIGHT-POINTING TRIANGLE}", next_page),
+            NavButton("\N{BLACK RIGHT-POINTING DOUBLE TRIANGLE WITH VERTICAL BAR}", last_page),
         )
         return buttons
 
-    async def _next(self, _) -> None:
-        self.current_page_index += 1
-        self.current_page_index %= len(self.pages)
-
-    async def _prev(self, _) -> None:
-        self.current_page_index -= 1
-        if self.current_page_index < 0:
-            self.current_page_index = len(self.pages) - 1
-
-    async def _first(self, _) -> None:
-        self.current_page_index = 0
-
-    async def _last(self, _) -> None:
-        self.current_page_index = len(self.pages) - 1
-
-    async def _stop(self, _) -> None:
-        self._msg.app.unsubscribe(hikari.ReactionAddEvent, self._process_reaction_add)
-        await self._msg.delete()
-        self._msg = None
-
     async def _process_reaction_add(self, event: hikari.ReactionAddEvent) -> None:
         if (
             event.user_id != self._context.message.author.id
@@ -144,7 +180,7 @@ class Navigator(abc.ABC, typing.Generic[T]):
 
         for button in self.buttons:
             if button.is_pressed(event):
-                await button.press(event)
+                await button.press(self, event)
                 if self._msg is not None:
                     await self._edit_msg(self._msg, self.pages[self.current_page_index])
                     try:
@@ -184,7 +220,7 @@ class Navigator(abc.ABC, typing.Generic[T]):
         intent_to_check_for = (
             hikari.Intents.GUILD_MESSAGE_REACTIONS
             if context.guild_id is not None
-            else hikari.Intents.PRIVATE_MESSAGE_REACTIONS
+            else hikari.Intents.DM_MESSAGE_REACTIONS
         )
         if not (context.bot.intents & intent_to_check_for) == intent_to_check_for:
             raise hikari.MissingIntentError(intent_to_check_for)
@@ -236,7 +272,7 @@ class StringNavigator(Navigator[str]):
                 paginated_help = pag.StringPaginator()
                 for l in thing_that_creates_a_lot_of_text.split("\\n"):
                     paginated_help.add_line(l)
-                navigator = nav.StringNavigator(paginated_help.pages)
+                navigator = nav.StringNavigator(paginated_help.build_pages())
                 await navigator.run(ctx)
 
     """
